Enum prolog_parser::ast::Constant [−][src]
pub enum Constant {
Atom(ClauseName),
Char(char),
Number(Number),
String(StringList),
Usize(usize),
EmptyList,
}Variants
Atom(ClauseName)Char(char)Number(Number)String(StringList)Usize(usize)EmptyList
Methods
impl Constant[src]
impl Constantpub fn to_atom(self) -> Option<ClauseName>[src]
pub fn to_atom(self) -> Option<ClauseName>pub fn to_integer(self) -> Option<Rc<BigInt>>[src]
pub fn to_integer(self) -> Option<Rc<BigInt>>Trait Implementations
impl Clone for Constant[src]
impl Clone for Constantfn clone(&self) -> Constant[src]
fn clone(&self) -> ConstantReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)1.0.0
[src]Performs copy-assignment from source. Read more
impl Hash for Constant[src]
impl Hash for Constantfn hash<__H: Hasher>(&self, state: &mut __H)[src]
fn hash<__H: Hasher>(&self, state: &mut __H)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
[src]Feeds a slice of this type into the given [Hasher]. Read more
impl Display for Constant[src]
impl Display for Constantfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for Constant[src]
impl PartialEq for Constantfn eq(&self, other: &Constant) -> bool[src]
fn eq(&self, other: &Constant) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
fn ne(&self, other: &Rhs) -> bool1.0.0
[src]This method tests for !=.
impl Eq for Constant[src]
impl Eq for Constant